# LSE's Knowledge Beyond Boundaries Application
### Date Applied
13-Mar 2022
### Due Response
03-May 2022
### Outcome
29-Apr 2022: Success!
### Title
Collaborating on An Incomplete History of Research Ethics
### Presentation Type
Poster: a 3-5 minute ‘flash talk’ presentation accompanied by a poster
### Abstract
Conducting research responsibly requires training in research ethics. An Incomplete History of Research Ethics provides a tool to support researchers, regardless of their field of inquiry, to develop reflexivity in regards to their work. By compiling "stories" from history, this project provides relevant insights through engaging story-telling and enticing formats, such as Tiki-Toki (https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/). It also draws from diverse fields, dispelling a notion of research ethics as pertaining only to clinical research (this would be the subfield of bioethics). Finally, the project engages with non-Western philosophical traditions, accounting for the complexities of modern science and society.

The poster presentation will have two parts. Firstly, I introduce the project and its usefulness as a resource in research ethics training. I draw on my experience as a provider of research ethics training at the Alan Turing Institute to make this case. Secondly, I outline the importance of going beyond epistemic boundaries in developing An Incomplete History of Research Ethics. The project's collaborative spirit is captured by the use of GitHub (https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics). I will outline ways to contribute to the project via the GitHub repository, and invite the audience to join me to develop this inherently multidisciplinary resource.

---

# Collaborations Workshop 2022 Lightning Talk
### Date Applied
21-Feb 2022
### Outcome
See the slide [here](https://doi.org/10.5281/zenodo.6384393).
### Title
Learning from An Incomplete History of Research Ethics
### Abstract
An introduction to stories from An Incomplete History of Research Ethics that are relevant to data science and AI ethics.
### Theme
Ethics

---

# Collaborations Workshop 2022 Mini Workshop
### Date Applied
19-Jan 2022
### Due Response
18-Mar 2022
### Outcome
21-Feb 2022: rejection with possibility of delivering a lightning talk (see above entry).
### Abstract
The ethics of software design, development and research are becoming increasingly important in the software engineer’s toolkit. Being able to reflect on the moral implications of their work will only gain traction as technological advancements have more significant societal impacts. In this mini-workshop, I wish to introduce a new resource for software engineers and researchers to engage with the questions their work raises. An Incomplete History of Research Ethics (The Timeline, for short) provides a growing compilation of thought-provoking stories from our shared past. Using diverse and engaging formats, it enables varied audiences inside and out of knowledge-production to conduct and critique research as a product of its social context. The workshop will begin with an introduction to the ways computer scientists and researchers more generally can collaborate and help develop a sustainable learning resource. I then introduce three developing stories from The Timeline that are relevant to data science and technology. Firstly, I share reflections that preempt current discourse about non-fungible tokens (NFTs) from the 1930s. Secondly, I outline an 1890's paper that raises concerns about the impact of contemporary technology on individuals’ right to privacy. Thirdly, I introduce the modern implications of the early development of cartography or map-making. Finally, I welcome participants to critique The Timeline (specifically asking ways to make it more relevant still to AI and data science researchers), and invite them to become collaborators on the project.
### Theme
Ethics
### Session Description
One aim is to gather feedback on how to make An Incomplete History of Research Ethics more useful to CW’s audience. My previous role in research ethics at the Alan Turing Institute showed me that data scientists often lack case studies to prompt reflection. I want to ensure that The Timeline is helpful for their cutting-edge work. More importantly, the mini-workshop should prompt the audience’s reflection on both the ethics of their work and the diverse nature of research ethics. By drawing on the history of current debates, the mini-workshop aims to make the history of research ethics (and The Timeline in particular) relevant to modern technologies. The impact of the session will be measured in the collaborations on the project that result from the session.

---

# OLS-5 Application
### Date Applied
11-Dec 2021
### Outcome
09-Feb 2022: Success! See the work [here](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics/tree/main/In%20the%20media/OLS-5).
### Title
A History of Research Ethics
### TL;DR
A [GitHub repository](https://github.com/Ismael-KG/A-History-of-Research-Ethics/) and community to engage with people interested in reading, sharing and contributing to [_A History of Research Ethics_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/).
### Keywords
History of Science, Philosophy of Science, Research Ethics
### Project
#### Describe your project
[_A History of Research Ethics_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/) is a free, online resource for researchers, governance professionals, and even college students to learn about science and ethics, and be inspired to develop practical tools for the assurance of adequately conducted research.

A key purpose of _A History of Research Ethics_ is to demonstrate the variety of disciplines and backgrounds that research ethics can draw on. In other words, interdisciplinarity is critical for its success. This means both interdisciplinary contributions _and_ adapting to audiences from diverse fields and sectors.

By embracing the collaborative nature of GitHub and OLS’s open science community, I expect to take _A History of Research Ethics_ to its next stage of development.

### Problem
#### What problem(s) are you solving with this project?
One significant problem is solved by _The Timeline_: the myth that research ethics pertains to only a few heinous medical investigations conducted in the twentieth century. This is solved by providing an interactive timeline on [Tiki-Toki]( https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/) that illustrates very diverse events that (i) are relevant to research ethics and (ii) are spread out through history, as far back as the fourth millennium BCE..

It is key to this project that research ethics is acknowledged as a complex field by communities that are equally diverse. I am here speaking of _epistemic diversity_, or diversity of knowledge domains. Generally, the complexity of research ethics might be acknowledged by philosophers; and the depth of the history of science acknowledged by anthropologists and historians. The interactive format of Tiki-Toki enables these ideas to be conveyed to much wider audiences.

### Achievements
#### What concrete achievements do you want to accomplish during the OLS program?
Key achievements include:
* Gathering feedback, both on the content of _A History of Research Ethics_ and on the way GitHub is used as a repository. _(Nb.: this is not a “SMART” goal.)_
* Create a sustainability plan to ensure that future contributors have clear “protocols” to follow, but also that contributors needn’t have any knowledge of GitHub – it must all be spelled out clearly and without jargon. The protocols currently in place are [here]( https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/main/Protocols.md).
* Establish clear links between story categories and potential audiences. Currently captured in “[Protocol 7: Public Engagement](https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/main/Protocols.md#protocol-7-public-engagement), Intended Audiences”, I will work with OLS to understand how different audiences can gain from _The Timeline_ and create more suitable protocols.
* Gain maybe two contributors, as defined by [Protocol 3](https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/main/Protocols.md#Protocol-3-Contribution-Types).

### Open
#### What inspires you to work openly in research?
Very roughly, _epistemology_ is the field that studies what knowledge is, how it is shaped, its purpose and its evolution. For decades, this philosophical field has challenged the notion that research is conducted by “lone geniuses”. Rather, the field of _social epistemology_ has gained traction. Social epistemology argues that knowledge is produced by and for social collectives.

Standing on the shoulders of great thinkers such as Ian Hacking, Miriam Solomon and Robert Merton, I draw on the open science movement to conclude that collaborative methods of knowledge-production can also be conducted openly. This is so that those who collaborate can learn together about the content they contribute to, and methods for collaboration. The goal is for collaborators to become advocates for social forms of epistemology.

### Challenges
#### What challenges have you faced in working in open science?
Two main challenges, although intricately linked. Firstly, the technical barriers. I have only worked in one open science community, and it was designed around its tool for collaboration: GitHub. Whilst I have come to terms with some of GitHub’s functions in recent months (and I promise I can use it for OLS-5!), I struggled in many ways to engage with the creation of the community's metascience book.

Secondly, I have faced an important cultural barrier. By relying on traditional open science tools such as GitHub, it can be difficult to be understood by fellow collaborators who are perfectly comfortable with the tool. I found that they struggled to empathise with the fact that I would spend so much effort in making small changes that I had no capacity to make more significant contributions. In other words, I have struggled with bringing diverse fields into otherwise very code-intensive communities.

### Learning
#### What are your learning goals in the Open Life Science program?
I want to learn how to engage with diverse and technical communities. I will take advantage of the OLS format to feel a part of a welcoming community, network with people with practical know-how in open science, and embrace GitHub once and for all!

Importantly, I want to improve in my social skills. I am generally quite the introvert. On top of that, I have been very isolated in recent months, so “re-learning” social skills will be of great value, and I think the OLS-5 cohort will be a kind group for me to engage with.

### Mentor
#### What do you expect from a mentor?
Kindness, patience, empathy, curiosity and structure. I would like a mentor who is interested in metascience, willing to advocate for my work, and/or prepared to help me network. (Networking is a key skill I have lost during the pandemic!)

I also don’t have a PhD, which I have found to be detrimental to my credibility in the past. I would welcome a mentor from industry, or with know-how both within and without academia, but this is only a nice-to-have. I will be grateful to whomever becomes my mentor!
