### Protocol Protocol
Protocols for _An Incomplete History of Research Ethics_ are on different topics. Their one defining element is their flexibility. Neither of the below protocols are set in stone, nor shielded from critique. Rather, contributors should feel welcome to create issues to discuss ideas for improving these protocols as per Protocol 3. Please also note that "_An Incomplete History of Research Ethics_", "_The Timeline_" and "the project" are used interchangeably to refer to the present project.
### Navigate to a protocol:
* [Protocol 1: Code of Conduct](#Protocol-1-Code-of-Conduct)
* [Protocol 2: Referencing _The Timeline_](#Protocol-2-Referencing-The-Timeline)
* [Protocol 3: Contribution Types](#Protocol-3-Contribution-Types)
* [Protocol 4: Lifecycle of a Story](#Protocol-4-Lifecycle-of-a-Story)
* [Protocol 5: Style Guide](#Protocol-5-Style-Guide)
* [Protocol 6: Reliable Sources](#Protocol-6-Reliable-Sources)
* [Protocol 7: Public Engagement](#Protocol-7-Public-Engagement)
* [Protocol 8: Naming Conventions](#Protocol-8-Naming-Conventions)
* [Protocol 9: Technical Implementation](#Protocol-9-Technical-Implementation)
* [Protocol 10: Editorial Care](#Protocol-10-Editorial-Care)
* [Protocol 11: Networking at the Agora](#Protocol-11-Networking-at-the-Agora)

# Protocol 1: Code of Conduct
A key purpose of _An Incomplete History of Research Ethics_ is to demonstrate the variety of disciplines and backgrounds that can help gain a richer notion of research ethics. Whilst this "richness" needs spelling out, this is not the place for that. This is the place where we note the pernicious aspects of human nature, which become particularly salient when we encounter voices we are not accustomed to and perspectives that differ from our own in areas we are especially passionate about. The necessity for diversity in a project such as _A History of Research Ethics_ can result in clashes or conflicts. This code will continue to be improved, but it sets out two things: (i) expected behaviours when contributing to the present repository, and (ii) methods for resolution.

## Principles for Participation
Participating in discussions on the present repository means adhering to the following principles, adapted from All European Academies ([2011](https://allea.org/portfolio-item/the-european-code-of-conduct-for-research-integrity-2/)):
* _Duty of care_ is paramount. We are all here to learn from one another and that requires that we all feel safe and included in discussions, even when they do get heated. Kindness is key to the success of _An Incomplete History of Research Ethics_.
* _Honesty_ in engaging with views and interpretations that differ from our own, and in providing evidence to argue for one's position. It also means being honest about the contributions we make to _The Timeline_.
* _Humility_ relates to honesty insofar that we must be honest with our own limitations. Contributors to _The Timeline_ must be open to others' perspectives and accepting that someone else just knows more about a certain domain.
* _Charitability_ is about treating all perspectives with the same due diligence. No perspective is automatically better than another, and adequate argumentation is necessary to overcome differences.
* _Open communication_ requires that discussions about the repository and published stories be maintained publicly. This is not to enforce full transparency. There will be cases where an author of a story might have got something "embarrassingly wrong" ([me](https://github.com/Ismael-KG)) and should be messaged privately. This is perfectly acceptable. (Changes are then tracked through the repository.) But the go-to method for discussing and improving stories is by opening [an issue](https://github.com/Ismael-KG/A-History-of-Research-Ethics/issues) using the "Lightbulb Moments 💡" template.
* _Reliability_ of sources drawn on when contributing to _The Timeline_. This principle is captured by [Protocol 6](#Protocol-6-Reliable-Sources).
* _Impartiality_ from political, financial or ideological pressure groups. This does not mean you are to be "apolitical" (the history of humanity is deeply political), but contributing with some political, financial or ideological agenda can lead to biased readings of historical events.
* _Sustainability_ of _The Timeline_ hinges on contributors being aware of this code of conduct and broader governance procedures. The Protocols capture guidelines for all contributors to adhere to.
## Resolution: Reconciliation or Reprimand
_The Timeline_ is a private endeavour. There are no formal mechanisms for mediation, but personality clashes and unassailably divergent communication styles sometimes meet. The above eight principles will guide behaviours and be drawn on to establish whether an engagement is in good faith or crosses a line. However, whistleblowers and victims will always be taken seriously, and the principles will adjust if needed. Three approaches to conflicts between contributors are listed below:
1. The priority when handling relationships that have soured will be reconciliation. The key is that all contributors get on together. If, through dialogue, we can set our differences aside and move on in tandem, so it shall be!
2. When problems have gone too far, we can aim for tolerance; the parties shall need to learn to tolerate that the other is also a part of the project. However, the involved parties will be assigned different tasks to work on, so that encounters are kept to a minimum.
3. In the unfortunate case that a contributor posts unkind or unhelpful comments that clearly break with the eight principles, they will wither [be blocked](https://docs.github.com/en/communities/maintaining-your-safety-on-github/blocking-a-user-from-your-personal-account) or given a warning after a discussion with [Ismael-KG](https://github.com/Ismael-KG), which will only take place if they are deemed redeemable.

# Protocol 2: Referencing The Timeline

_A History of Research Ethics_ is intended to be a useful resource for various audiences, and the best way to reach these audiences is by being shared as much as possible! This protocol is of particular use to ⭐ **Advocates** ⭐, as per [Protocol 7](#Protocol-7-Public-Engagement) This protocol attempts to supplement (and certainly does not override) the [citation](https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/ddb6497dcf3c88fff4d19693a711da1f9a6e24f6/CITATION.cff) file and the [licence](https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/main/LICENCE.md). As the licence is [CC-BY 4.0](https://creativecommons.org/licenses/by/4.0/), references to _The Timeline_ must be attributed appropriately.
  
In the case of sharing screenshots of _A History of Research Ethics_ in presentations or other media, please share either of the below lines on the slide:
> © 2021 Ismael Kherroubi Garcia

> DOI: 10.5281/zenodo.5731453

In-line references to _A History of Research Ethics_ can be made by referencing either:
* Kherroubi Garcia et al., 2021; or, if a specific story is being referenced,
* Kherroubi Garcia et al., 2021: §[story name].

For example:
> Kherroubi Garcia et al. (2021) claim [...].

> _The Timeline_ (Kherroubi Garcia et al., 2021) provides a case in point.

> _A History of Research Ethics_ (Kherroubi Garcia et al., 2021) has failed to demonstrate [...].

> Autonomy is a key value in modern bioethics (Kherroubi Garcia et al., 2021: §The Principle of Patient Autonomy).

The preferred citation style in bibliographies (as the [citation](https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/ddb6497dcf3c88fff4d19693a711da1f9a6e24f6/CITATION.cff) file might be unclear) is: Kherroubi Garcia et al. (2021) [story name if you reference only one, In] _A History of Research Ethics_, DOI: [10.5281/zenodo.5731453](https://doi.org/10.5281/zenodo.5731453). For example:

> Kherroubi Garcia et al. (2021) _A History of Research Ethics_, DOI: [10.5281/zenodo.5731453](https://doi.org/10.5281/zenodo.5731453)

> Kherroubi Garcia et al. (2021) The Principle of Patient Autonomy, In _A History of Research Ethics_, DOI: [10.5281/zenodo.5731453](https://doi.org/10.5281/zenodo.5731453)

# Protocol 3: Contribution Types
This protocol establishes the roles that contributors may fall under. Similar to [CRediT](https://casrai.org/credit/), the point is to acknowledge the different types of effort contributors bring to the wider project. In the case of _The Timeline_, emphasis is on types of contribution rather than categorising contributors. This can help if, in the future, a contributor wants to show evidence (to potential employers, etc.) that they can make a certain type of contribution - that they have a certain skill. The below taxonomy can also be used by potential contributors to be inspired as to how they might support the creation and maintenance of _A History of Research Ethics_.

It is worth noting that there is a low bar for becoming a contributor to this project. At present, practically taking the time to discuss the project with me (@Ismael-KG) will render you a contributor. I intend that to continue being the case, and to be clear that all contributions are deemed equally valuable.

Contributions then fall under one of two broad categories: _sustainability_ or _stories_. Each of these, in turn, are broken down as follows:

## Sustainability
Sustainability contributions are those that relate to the GitHub repository and have little to do with the content of stories.
* **Engineering:** these are contributions that have to do with (i) how the GitHub repository is managed and arranged, (ii) how different sites host content pertaining to the timeline, and (iii) maintenance of the present platform (Tiki-Toki) and its eventual migration to a better platform (hopefully).
* **Policy-making:** this is about writing and improving protocols. For example, on the review process, the code of conduct, or even this very taxonomy!
* **Communications:** these include contributions relating to strategising about social media-usage, but also spreading the word online (at present, communications is mostly @Ismael-KG's tweets, which don't get very far!).
* **Ideation:** this is a broad type of contribution to acknowledge that both stories and protocols can result from discussions that can be held on GitHub issues or offline.

## Stories
The content of the timeline can be improved and maintained by the following contribution-types:
* **Conceptualisation:** contributions of this sort occur early on in the story-creation life-cycle. This can amount to something as simple as drawing a fellow contributor's attention to some historical event that might be worth capturing in _The Timeline_.
* **Research:** research contributions are useful during the conceptualisation and story-writing stages. It is mostly about providing links to useful resources.
* **Authorship or co-authorship:** this is when a new story has been drafted in full by one or more people.
* **Review:** providing reviews requires expertise on the stories to be reviewed. It is about ensuring the accuracy of claims and quality of argumentation. Reviews are "higher-level" than copy-editing.
* **Proofreading:** proofreeding is when contributors scour stories for syntactical, grammatical and spelling mistakes.
* **Copy-editing:** this is a thorough analysis of a text's consistency and clarity, and ensures that the text is also in line with _The Timeline_'s style guide (yet to be made). Further details on this type of contribution are available in [Protocol 10: Editorial Care](#Protocol-10-Editorial-Care).

## Recognition
It would be unfair to create a system where anybody can contribute yet nobody gains recognition. As contributions grow, sustainability ones will be acknowledged at the end of protocols. For example, a protocol might end with "This protocol was designed by @/so-and-so."

Similarly, stories will end with an acknowledgements section, listing stories-type contributions and the people behind them.

To acknowledge contributors in one place, contributors are also listed in [Contributors.md](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics/blob/main/Contributors.md) alongside a link to what they helped develop.

The principles of _honesty_ and _humility_ are particularly important to recognition, as we must truthfully recognise both the work we conduct, and where we have requested for others' help.

# Protocol 4: Lifecycle of a Story
There are eight ateps to the development of stories for _The Timeline_. Each one can be repeated, and you can always revisit previous steps. You are strongly encouraged to develop stories (i) with the help of others, and (ii) by creating an issue using the "Conceptualisation 🖊️" template. This Protocol is written with potential authors in mind. For more details on reviewing contributions, see [Protocol 10: Editorial Care](#Protocol-10-Editorial-Care).

## Step 1: Idea generation
This is where you can put your most creative self to work. There are at least two approaches to idea generation:
* **Top-down idea generation** means thinking big and whittling down. You might be curious about the warring states period in Ancient China, or perhaps evolutionary psychology, or anything! From this broad interest of your own, the goal is then to establish an event that has a clear link to a question for research ethics.
* **Bottom-up idea generation** is about starting with an event or concept you are aware of, and then studying the broader historical context in which that phenomenon originated. The link between the historical event and topic for research ethics can be established through the process of studying the historical context.

Once you have clarity on the idea or feel you need support to develop it, raise an issue following the "Conceptualisation 🖊️" template and invite discussion by using the "Help Wanted" label.

## Step 2: Compiling Resources
You are encouraged to employ diverse sources of information when at the idea generation stage. Once an idea becomes clearer, you should draw on sources that adhere to [Protocol 6](#Protocol-6-Reliable-Sources).

## Step 3: Finding coherent narratives
With the general idea and the vast quantity of resources you have found, it is finally time to establish the outline of the story and any philosophical arguments to be put forward. [Protocol 5](#Protocol-5-Style-Guide) can help you structure your thoughts.

Also, don't be afraid to discard academic papers, articles or books that become irrelevant. The story must be clear and coherent. This is not to say you should adjust evidence to your own narrative (that would be deeply unethical), but that you must focus on clear arguments and not lead readers astray by introducing too many topics or events.
  
## Step 4: Create a WIP file
Having made it to step three, the story will have earned a file in the "Works_In_Progress" folder! You can create a "shell" story with a title, date and intro by either:
1. Opening [the folder](https://github.com/Ismael-KG/A-History-of-Research-Ethics/tree/main/Works_In_Progress) >> click "Add File" at the top right >> select "create new file" >> Name the file following [Protocol 8: File Naming Conventions](#Protocol-8-File-Naming-Conventions) >> Copy and paste the [story template](https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/68e1e4062927e08a5c4cbe7d91ed9ed7a2cd260b/A%20Template%20for%20Stories.md) into the new file >> Input the basic information you have so far, making sure to mark `wip: true` and indicate the number of the relevant "Conceptualisation 🖊️" issue after `issue: ` (for example: `issue: 72`).
2. Or just mentioning [@Ismael-KG](https://github.com/Ismael-KG) in the "Conceptualisation 🖊️" issue for the story and ask to have the file created. Be clear about the event's title, date and intro.

To show how far you've made it on the "Conceptualisation 🖊️" issue, add the labels "good first issue" (following [convention for issues where contributions are relatively easy](https://github.blog/2020-01-22-browse-good-first-issues-to-start-contributing-to-open-source/)) and "WIP". This also helps potential contributors see they can help you by listing your issue [here](https://github.com/Ismael-KG/A-History-of-Research-Ethics/issues?q=is%3Aopen+is%3Aissue+label%3A%22good+first+issue%22+label%3A%22Help+wanted%22+label%3AWIP).

## Step 5: Draft and re-draft the story
And re-draft again and again and again! You can choose to do this publicly using [HackMD](https://hackmd.io/) or your preferred collaboration tool, or you can draft work privately. Be open to holding discussions on GitHub using the "Conceptualisation 🖊️" issue, but don't feel pressured to share things publicly until you feel comfortable to do so.

## Step 6: Pre-Publication Peer Review
Once you are happy to share what you have written with the help of collaborators, it's time to get it peer reviewed!

GitHub is not intended to be used as a text editor. For this reason, once stories are drafted, they are to be pasted into this [HackMD document](https://hackmd.io/VW6SvaOYTemXnOd4SMcC4Q?both), which uses markdown (similarly to GitHub) but is much easier to comment on. This will require [signing up to HackMD](https://hackmd.io/join).

Drafts are kept in the pre-publication document for a period of anything between nine and fifteen days, the last day of which will always be a Saturday. This allows for storiesto be uploaded "in bulk" on Sundays.

During the pre-publication review period, the HackMD document is re-shared publicly and people are encouraged to contribute and help improve the drafts.

## Step 7: Publish on GitHub
On the day after the end of the pre-publication peer review (a Sunday), the drafted story is to be revised one last time by its authors. Depending on the complexity of the comments received, their integration can be more or less swift. Don't feel like you need to adopt all the comments, or do so too quickly!

Once you are happy with the polished story, go to the WIP file you created in step 4, click the "edit pencil" at the top-right and paste the story! By following the steps, you will raise a pull request where you can ask for "reviewers." Add [@Ismael-KG](https://github.com/Ismael-KG) as a "reviewer" when creating your edits can be made to the WIP file. You might be asked to make some final changes, but the previous six steps are there to ensure not much (if anything) needs changing! Requests for changes be considered "copy-editing contributions".

## Step 8: Publish on [tiki-toki](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/)
[@Ismael-KG](https://github.com/Ismael-KG) can now go ahead and publish your new story on the tiki-toki platform, as he has the admin rights. Once this is done, there are just two more steps to follow:
  1. In the opening comment of the relevant "Conceptualisation 🖊️" issue, keep the title, date and intro, and replace the rest with the following text:
> `**This story has been published [on Tiki-Toki](insert the relevant Tiki-Toki link here), but please feel free to reopen this issue and make any suggestions below!**`

  2. Change the "Conceptualisation 🖊️" issue's labels to *only* the "Published!" one, and finally close the issue! 🎉

# Protocol 5: Style Guide
This protocol is intended for stories to adhere to some loose rules. By writing stories following the below, they can fit into a more consistent whole.

## All stories must have
* A short title
* An introductory line with less than 240 characters.
* A summary paragraph at the start to excite readers but also keep people from wasting their time if a text is not that relevant;
* At least one paragraph on basic historical context (e.g.: "the events took place as eugenics were gaining traction across the pond...");
* A clear message for researchers and/or research governance folk (e.g.: "we here see the importance of including perspectives from groups who have been historically marginalised from academia").

### Titles
Story titles must be under 70 characters and conform to one of the following styles (or result in an issue to expand this list if they do not meet these guidelines):
* Simple name of the institution or technology being discussed (e.g. [_A Bablylonian Library_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16443368!) and [_The Lunisolar Calendar_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16475774!)).
* The name of texts without clear authors (e.g. [_Edwin Smith Surgical Papyrus_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16456093!), [_Ebers Papyrus_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16457367!)).
* Books and papers with clear authors will be called "[book title], by [author's full name, or surnames if two authors, or "first author surname et al." if more than two authors]" (e.g. [_Hind Swaraj, by Mahatma Gandhi_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16443706!), [_The Principles of Humane Experimental Technique, by Russell and Burch_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16443919!)).
* Titles of the coined terms theme (#3) will be called "[author's full name, or surnames if two authors, or "first author surname et al." if more than two authors] coin(s) ["coined term"]" (e.g. [_Émile Durkheim coins "collective consciousness"_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16554598!), [_Molyneux et al. coin "neglected tropical diseases"_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16638090!)
* Titles in the "Legislation [...]" category (#11) will be the name of the text being analysed (e.g.: [_Code of Hamurabi_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16462371!), [_The Belmont Report_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16444358!)).
* Stories in the research tragedies category (#13) will be titled by "[common plot], Part [Roman numbers, I, II, III, IV, V, VI, VII...]" (e.g. [_Heliocentrism, Part I_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16443483!)).

### Introductory lines
These are very short, are to be kept under 240 characters, and should:
* Introduce the main event, and/or
* Introduce the concept that is relevant to ethics.

A case with both points is found in [Princess Dashkova's story](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16575859!):
> Princess Dashkova Yekaterina Romanovna Vorontsova is appointed to direct the Petersburg Academy of Arts and Sciences, establishes the Russian Academy, and helps reflect on gender stereotypes and allyship.

But both points needn't be present, as 240 characters is a tight limit. The event is, for example, the only element present in the case of [_Comptes Rendus_](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16443638!):

> Following some, perhaps unpleasant, exchanges with journalists, "Comptes Rendus" becomes the French Académie's academic journal.

A story's intro that emphasises only the second point can be found in the [Humboldt University](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16443616!) story:
> "Academic freedom" gains form in Humboldt’s University of Berlin, in Germany.

### Summaries
Must include at least one sentence on:
* Sociohistorical context;
* The event the story will study; and
* The key ethical question that the story raises.

### Historical Context and clear message
This is really the body of the story, and the following "structures" subsection provides some guidance.

## Structures
The basic structure for stories to follow:
1. The **historical scene** must be set to absorb the reader into this different world, whether it be a year or a thousand years earlier. Sociohistorical context means answering to where, when and why the event took place.
2. **The event itself** must respond to _what_ and _how_. _What_ requires a description of the particular event. _How_ means engaging with the continuous nature of, well, time.
3. The scene is set for an **Ethical Quandary™️**. It is here where different [_dramatic structures_](https://en.wikipedia.org/wiki/Dramatic_structure) might be employed. Is it all smooth-sailing until **panic**! A nefarious application of some technology! Or, perhaps the quandary section begins with sorrow and woe — unforgettable pain or untenable obstacles — and we gradually come to see the light. **The point is** that we can draw on some degree of theatricality. This is both (i) so that the narrative is captivating and (ii) that the very palpable distresses that complex ethical questions can come to cause are made as salient as possible. (Think Hacking's [1996](https://doi.org/10.1093/acprof:oso/9780198524021.003.0012) "sensationalism.)
4. The **conclusion** must outline either (i) key ethical concepts gained from (3) above, (ii) questions for researchers to reflect on in their work, and/or (iii) thoughts for research governance folk to draw on when designing or reviewing policies. Ideally, the conclusion is _not_ a summary of (1), (2) and (3), as we might find in an academic philosophy paper.

## Communication style
Given the diverse audiences _The Timeline_ seeks to adapt to, the below guidelines emphasise the need to break down barriers.
* Prioritise simple terminology and explain any technical jargon _immediately_. By technical jargon, I mean terms used by a particular professions and which are hard for others to understand. (See what I did there?)
* Don't be afraid of trying to be funny. _A History of Research Ethics_ is not a dull academic journal that almost purposefully alienates anybody who isn't in the academics' club already. Humour breaks down barriers between writers and readers.
* On breaking down barriers, take readers on a journey with you. Learn together and speak in terms of "we." For example: "In this story, _we_ will visit the complexity of conducting research in environments where _we_ don't share the training that _our_ colleagues have" (roughly).
* The language employed can be informal. Feel free to use contractions, for example, and see Nordqist ([2020](https://www.thoughtco.com/informal-style-prose-1691170)) for more on informal language. But informality must not detract from clarity, or undermine the severity of stories or certain parts of stories. More formal tones can be employed when discussing more technical aspects of stories, either the ethical frameworks that they hint at, or any field-specific knowledge that might need spelling out.

# Protocol 6: Reliable Sources
<img width="538" alt="@EthicsInBricks on Twitter provide an image of a LEGO version of Diogenes saying 'don't believe everything you read online'" src="https://user-images.githubusercontent.com/64027166/143767239-c31e6d14-3b26-4a7c-94ce-83d5270e9c6a.png">

The quality of stories in _A History of Research Ethics_ will depend on their accuracy. Accuracy in recounting historical events - from their dates to their main characters and broader context - requires drawing on reliable sources. Whilst no source is shielded from corruption and history is often written by the vistors, I suggest taking a leap of faith and employing a variety of some of the following sources when backing up claims in stories:
* Academic journals
* Dictionaries
* Documentaries
* Encyclopedias
* News articles that employ clear references
* Recorded presentations or conferences

This is not to say that other sources cannot be employed or that these are perfect. Feel free to work with _Wikipedia_, for example, when looking for ideas. _Wikipedia_ often links to sources that are best drawn on to adhere to the principle of _Reliability_.
  
Finally, _Reliability_ does not amount to the "credibility" of authors one draws on. Plenty of high-quality scholarship is created every day without entering the "canon" (the literature that is seen as an established source of truth within some field). Furthermore, authors who are in the "canon" may have violated ethical principles or even broken the law (just consider what is discussed in _Research Tragedies_!). It is important, then, to _critically_ cite reliable sources.

# Protocol 7: Public Engagement
This protocol briefly introduces (i) the intended audiences of _The Timeline_, (ii) some platforms to consider for sharing the project and example calls to action, and (iii) what it means to become an ⭐ **Advocate** ⭐.

## Intended Audiences
The potential audience of _An Incomplete History of Research Ethics_ is formed by:
* **People who want to learn more about research ethics or the history of science.** For these audiences, who do not need to be experts in any particular field, make sure that titles are short and clear, that the intro line describes the importance of the story, and that the abstract (first paragraph) is clear as to what the event entailed and why it carries "ethical significance."
* **Research governance folk**, such as legal teams, policy makers, and even human resources departments. This audience requires that the timeline not ignore the important role of legal frameworks and legal literature in shaping modern research ethics. This audience also requires that the very diverse parties who influence the implementation of research governance -- more or less wittingly -- have their voices heard. "Technical accuracy" in describing scientific findings, for this audience, can be seen as less important than actionable guidance.
* **Researchers**, by which I mean the infinite range between master's students in theology and tenured professors in astrophysics.
## Platforms
These diverse audiences require using different platforms to reach them. The broader the range of employed platforms, the better, although each requires its own work and should always link back to Tiki-Toki or GitHub:
* The present [repository](https://github.com/Ismael-KG/A-History-of-Research-Ethics) is where all changes are made, ideas shared and changes tracked. The DOI means the repo can be releasedon [Zenodo](https://zenodo.org/record/5731453#.YaT78tDP02w), and [CiteAs](https://citeas.org/cite/10.5281/zenodo.5731453).
* [Tiki-Toki](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/) is the visually appealing platform employed for sharing stories, right after they have been shared on the repository.
* [Medium](https://medium.com/) can be used to share series of related stories. The first of these was about the four oldest European science academies (see the first of the six-part series [here](https://ismaelkg.medium.com/internal-politics-in-europes-oldest-science-institute-2b265c130da1)). The reason Medium might be useful is its simple blog format, where stunning images can be shared, unlike on Tiki-Toki.
* [Twitter](https://twitter.com/home) is a great place to share links, find possible readers, and connect with potential contributors.
* [LinkedIn](https://www.linkedin.com/) also hosts blog posts and shorter status updates. It can be used to specifically reach professionals in governance and policy-making.
## Calls to Action
Audiences are also encouraged to become contributors. For this reason, when sharing tweets, blog posts, etc., there must be a clear call to action. Don't forget to link back either to Tiki-Toki or GitHub!

Example calls to action:
> Read more on [Tiki-Toki](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/)!

> Please contribute via [GitHub](https://github.com/Ismael-KG/A-History-of-Research-Ethics)!

> See what stories can gain from your review on [HackMD](https://hackmd.io/VW6SvaOYTemXnOd4SMcC4Q?both)!

> Join the conversation by tweeting #AnIncompleteHistoryOfResearchEthics https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/
## Advocacy
In cases where very kind and supportive people share the joys of _The Timeline_, they must, of course, be celebrated! 🎉

Raise an issue using the "Communications 🌐" template to share any external references to _The Timeline_. In the case that a reference is made by someone who is not a contributor, but shared _A History of Research Ethics_ as a useful resource or fun project, consider reaching out and asking whether they would like to be listed as an ⭐ **Advocate** ⭐ in [In the media.md](https://github.com/Ismael-KG/A-History-of-Research-Ethics/blob/ceb149891ba7983c5cac03bb40a72b824e9556ee/In%20the%20media.md).

Protocol 1's principles of _impartiality_ and _charitability_ are crucial to ensure the reliability of sources.
* _Impartiality_  amounts to your own background as a contributor. Whilst we all - wittingly or not - align to some ideology or other, we must (i) seek out sources that might surprise us or not conform to our prejudices, but also (ii) critically evaluate sources. For this reason, various sources must be drawn on to corroborate statements and the validity of analyses.
* _Charitability_ is necessary when engaging with sources where arguments are unclear to our minds. We must be open to engaging with these in good faith, and begin by giving them the benefit of the doubt. In other words, work from the assumption that sources are clear and rational. Then, provide charitable interpretations. These can then be critically evaluated and refuted on clearer grounds.

## Badges
Contributors are encouraged to celebrate that they have contributed to the project by weairing a badge on their GitHub profile! The badge appears as follows:

[![Contributing An Incomplete History of Research Ethics](https://img.shields.io/badge/Contributing-An%20Incomplete%20History%20of%20Research%20Ethics-red)](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics)

To add the badge to your GitHub profile
1. Go to `github.com/[your user name]/[your user name]` (For example, @Ismael-KG would go to `github.com/ismael-kg/ismael-kg`
2. Click on "Edit README"
3. Add the following:
`[![Contributing An Incomplete History of Research Ethics](https://img.shields.io/badge/Contributing-An%20Incomplete%20History%20of%20Research%20Ethics-red)](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics)`
4. Click "commit" towards the bottom of the screen to confirm the change. You can then visit `github.com/[your user name]` to see how the badge fits!

# Protocol 8: Naming Conventions
Although GitHub is not ideally used to navigate something like _The Timeline_, it is helpful to keep files ordered in a coherent manner to faciltate the repository's maintenance.

To do so, [Works_In_Progress](https://github.com/Ismael-KG/A-History-of-Research-Ethics/tree/main/Works_In_Progress) and published [Stories](https://github.com/Ismael-KG/A-History-of-Research-Ethics/tree/main/Stories) must be named as follows:
>[BCE or CE] YYYY [Story Title]

For example:

<img width="281" alt="image" src="https://user-images.githubusercontent.com/64027166/146543563-9517b399-6100-48d9-8885-4792de06c70c.png">

This means that BCE stories will be ordered backwards, which is something to keep in mind when browsing the present repository.

# Protocol 9: Technical Implementation
(Protocol Under Construction 🛠️)

# Protocol 10: Editorial Care
_An Incomplete History of Research Ethics_ is not an academic journal with the usual structures in place, such as editorial staff. Rather, it is about creating content and disseminating it as a community. Some structure is proposed in [Protocol 3](#Protocol-3-Contribution-Types) regarding ways one can contribute, including reviewing, proofreading and copy-editing stories. The present protocol reinforces the principle of _Duty of Care_ listed in the [Code of Conduct](#Protocol-1-Code-of-Conduct) to ensure these three contribution types in particular are made to the standards of Lau's ([2022](https://medicalhealthhumanities.com/2022/02/07/notes-toward-an-ethics-of-editorial-care/)) _Ethics of Editorial Care_.
  
Whether it is one's dominion of a certain research field (reviewer), their experience in producing content for _The Timeline_ (copy-editor), or their acute attention to detail (proof-reader), editors stand in a position of power before authors and co-authors because they are able to push back on original content, require more or less substantive changes, and postpone the publication of thoughtful work. The principle of _Duty of Care_ can be adhered to by reviewers, proof-readers and copy-editors following the measures below:

* Reviewers, proof-readers and copy-editors must _clearly_ describe the improvements they expect to see. For proof-readers and copy-editors, this means justifying why they note the errors they do and explaining how the changes they suggest improve the story.
* Reviewers and copy-editors must not "weaponise rigour" by suggesting that some "canon" authors must be cited. _An Incomplete History of Research Ethics_ was developed to point out less well-known aspects of human history, and citing authors from historically marginalised communities rather is encouraged (see [Protocol 6: Reliable Sources](#Protocol-6-Reliable-Sources)).
* Copy-editors must advocate for adherence to the _Code of Conduct_, where _Honesty_, _Humility_ and _Charitability_ can improve the quality of a story, as authors are encouraged to acknowledge their limitations and engage with the works they cite in good faith.
* Copy-editors are encouraged – where a draft publication is not to a great standard – to arrange calls with the authors they are reading. The copy-editor can then provide general advice but also check that the authors are happy to receive a lengthy review. The point here is to avoid the dispiriting feeling one might get from having their work "rejected."
* Copy-editors must not single-handedly block a publication. Blocking publications can only be done in extreme cases where there is a clear breach of the Code of Conduct. In either case, this will require action through the _Resolution_ mechanism in said code.

# Protocol 11: Networking at the Agora
Various activities can be set up to ensure continued engagement with An Incomplete History of Research Ethics. The Agora is where such events take place.
  
### Onboarding Sessions
These can be one-to-one or in small groups, and are delivered by @Ismael-KG on an ad-hoc basis. Those who are new to the project will be invited to attend such a session to:
* Get to grips with the Code of Conduct
* Get to grips with how the project uses GitHub
* Identify suitable contribution types (see [_Protocol 3_](#Protocol-3-Contribution-Types))
* Learning what you want to gain from the community

### Other activities
As the community grows and to facilitate networking, the agora can host Randomised Coffees & Teas, book clubs, and Sustainability Chats to workshop ideas for the future of _An Incmplete History of Research Ethics_.
