---
layout: story
title: "Nahua Metaphysics and Ethics"
story-status:
  wip: false
  issue: 133
historical-date:
  title: "1200"
  bce: false
  year: 1200
  source: https://doi.org/10.2307/482619
  author: Smith
  source-date: 1984
category: improving-research
authors: Ismael Kherroubi Garcia
contributors: James Maffie (review)
tags: ["Science Influencers","What We Value"]
media:
  source: "https://www.mexicolore.co.uk/images-5/597_11_2.jpg"
  caption: "A sage speaks to an audience with a torch between them. Source: Bernardino de Sahagún's \"Códice florentino\" (1979 facsimile edition published by the Biblioteca Medicea Laurenziana and the Archivo General de la Nación; supplied by Louise Burkhart)." 
intro: Pre-Hispanic Mesoamerican philosophy teaches us of the link between beliefs about the world, and how we engage with one another and our natural environment.
---
### Summary
The way we conceive of reality can have implications for how we conduct ourselves. More technically, theories of metaphysics can entail theories of morality. The pre-colonisation society of the Nahua people in Mesoamerica provides a case in point. Drawing mostly on Maffie's work, I will briefly introduce the metaphysics of the Nahua people, and show how it was intricately linked to their theory of ethics. This will support the claim that different notions of the world can affect how we pose research questions.

### The Story
Mesoamerica is a historical region that comprises the enormous land mass between modern-day Costa Rica and central Mexico, covering Nicaragua, El Salvador, Honduras, Guatemala and Belize (Carballo, [2020](https://doi.org/10.1093/oso/9780190864354.003.0002)). The cultures that flourished in the region are also the only ones that had developed written historical records prior to the European invasion, which began towards the end of the fifteenth century (Smith, [1984](https://doi.org/10.2307/482619): 153). These records are in four traditions - Maya, Zapotec, Mixtec and Nahuatl (Marcus, [1976](https://www.jstor.org/stable/2949303)). Nahuatl was the more extensively used language in Mesoamerica and I am drawing on this to speak of "Nahua people" rather than the more recognisable "Aztecs."

Unfortunately, no written records from before the European invasion of Mesoamerica remain. Thus, scholarship into prehispanic Mesoamerica relies strongly on works that emerged from the sixteenth century, precisely from the era where Spanish colonisers entered the scene. The complex relationship between Spanish colonisers and Nahuatl knowledge is discussed when introducing ["The Conquest" of 1519 to 1521](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16699328!). In the present story, I draw on the work of scholars who have compiled and analysed a great myriad of studies on ancient Nahuatl speakers. Specifically, the philosopher James Maffie's writings will help introduce the philosophical beliefs of the era and region.

In what follows, I begin by describing Nahua metaphysics, or their theory of reality. I then place their theory in the much broader tradition of pantheism. Finally, we will see how pantheism in general and Nahua metaphysics in particular lend themselves to certain notions of morality. I will conclude that, although Nahua metaphysics might seem outlandish to the modern researcher, it is important to note how philosophical conceptions of reality impact on the ethics of research.

Metaphysics is the philosophical study of reality. When we ask for the metaphysics of the Nahua people, we are asking for their conception of reality; what it means for stuff to exist. In the book Aztec Philosophy, James Maffie describes the metaphysics of Nahua people:

"At the heart of Aztec [Nahua] metaphysics stands the [...] thesis that there exists just one thing: continually dynamic, vivifying, self-generating and self-regenerating sacred power, force, or energy. The Aztecs [Nahuas] referred to this energy as teotl" Maffie ([2014](https://upcolorado.com/university-press-of-colorado/item/1991-aztec-philosophy): 21-22).

Two key ideas derive from Nahua metaphysics: that there is only teotl and that teotl is homogeneous. Teotl is homogeneous by being more of a process than a fixed thing; like a thunderstorm rather than a table ([ibid.](https://upcolorado.com/university-press-of-colorado/item/1991-aztec-philosophy): 23). Teotl can, thus, be understood as the process whereby the cosmos exists and regenerates itself. Teotl permeates all things and all things are, thus, parts of an endlessly self-generating and dynamic reality.

It is also helpful to consider negative conceptions of teotl, or what teotl is not:

"Teotl is nonpersonal, nonminded, nonagentive, and nonintentional" ([ibid.](https://upcolorado.com/university-press-of-colorado/item/1991-aztec-philosophy): 22).

Teotl does not intend, act or make decisions. There is a contrast that Maffie suggests for us to understand the elusive idea of teotl: it is not like the Judeo-Christian god. Teotl is very much immediate, omnipresent and inseperable from the cosmos, which teotl creates both within and out of itself ([ibid.](https://upcolorado.com/university-press-of-colorado/item/1991-aztec-philosophy): 23).

This notion of teotl, or reality being dynamic and ever-changing, is not unique to pre-Hispanic Mesoamerica. Two similar philosophies had already emerged across the two oceans that bathed Mesoamerica's shores.

Across the Pacific, Daoism had sought to make sense of the world by describing "the Way" (Dao) since the sixth century BCE. Dao sets a fluid, all-encompassing foundation to an equally processive cosmos (Hall, [2001](https://doi.org/10.1080/02691720110093315)). Across the Atlantic, the Ancient Greek philosopher Heraclitus had invited us to think of how we cannot step in the same river twice; how reality flows through time and is in constant flux.

These notions of a changing reality are significantly different, but teotl shares, at least with Dao, an explanatory function that helps make sense of the world's transitional nature. With teotl, the Nahua people also had at their disposal a theory of metaphysics whereby they could shape their own behaviours, whereby they could develop a theory of ethics.

Having established that teotl is the only reality as well as a constantly flowing force that generates and regenerates the cosmos it is a part of, we can begin to make sense of how Nahua people related with the world. To begin with, "reciprocity and well-balancedness" constituted a key component of Nahua ethics (Maffie, [2014](https://upcolorado.com/university-press-of-colorado/item/1991-aztec-philosophy): 277). The same way teotl continuously feeds and feeds from the cosmos, we find in Nahua people a desire to "authentically embody teotl [by preserving] balance and purity" (Maffie, [n.d.](https://iep.utm.edu/aztec/): §3.b.).

Nahua people, thus, developed rituals to partake in teotl. They developed and perfected "the practical know-how in performing ritual activities which genuinely present teotl" (Maffie, [n.d.](https://iep.utm.edu/aztec/): §3.b.). Some of these involved self-flagellation to transmit blood-based energy to the cosmos. In turn, they expected this to be reciprocated – as is teotl's nature – in the form of "human and agricultural vitality and fertility" (Maffie, [2014](https://upcolorado.com/university-press-of-colorado/item/1991-aztec-philosophy): 277). What was "reciprocated" responded to "higher, strongly evaluated goods" (Taylor, 1989, [1992](https://www.hup.harvard.edu/catalog.php?isbn=9780674824263); cited in Daniel, [2020](https://plato.stanford.edu/archives/fall2020/entries/communitarianism/): §2). Individual preferences, we could say, were subsumed by communitarian needs.

Thus, Nahua ethics embraced the fact that we live in communities. Through this simple idea, our ethics ought to acknowledge the role we play as participants of our society. Much like there being no distinction between teotl and the cosmos, personal ethics also becomes one with the preferences of the social environment.

It is important to note that the way Nahua people envisaged community included both humans and non-human beings, such as wind, fire, water, sun, moon, stars, lakes, rivers, mountains, trees, maize, animals, and insects; even houses, tools, cooking pots, codices, clothing and gemstones, to list a few (thank you to Maffie for this insight from the review!). This helps understand a further significant aspect of Nahua ethics entailed by their metaphysics; namely, their relationship with nature.

As communities are one with teotl, so too are humans "in, of, and one with the world" (Maffie, [2002](http://www.ludus-vitalis.org/ojs/index.php/ludus/article/view/585): 12). With teotl flowing through us, both our individual and collective wellbeing are interdependent with that of nature. It is for us, then, to accommodate to our natural environment.

It is clear from the case of Nahua philosophy that how we conceive of reality can shape not only how we interact with one another, but also how we treat – or should adapt to – the natural environment. There is a strong tie, in other words, between metaphysicss and morality. In the following section, I link modern metaphysical theories with how we decide what to research.

There is a historically contested question regarding (i) whether there exists a force that unifies the universe (like teotl), or (ii) whether there is some tiny element that constitutes the foundation of all things. Generally, modern Western philosophy and science have been driven by the notion that there is a fundamental particle (first the atom and now the quark) that all things can be broken down to. In the meantime, the view that some dynamic force permeates throughout existence has historically been shunned in the West. The "process philosophy" of the early-twentieth century Henri Bergson, for example, was often discarded for its "irrationality" (Herring, [2019](https://aeon.co/essays/henri-bergson-the-philosopher-damned-for-his-female-fans)). And the theoretical physicist David Bohm later had to seek support in Eastern forms of thought to develop his theory of mechanics (e.g. Ananthaswami, [2016](https://www.newscientist.com/article/2078251-quantum-weirdness-may-hide-an-orderly-reality-after-all/); see also the film [Infinite Potential](https://www.infinitepotential.com/)).

But the greater consensus in some region about one philosophical theory over another does not render it any more valid. What it does do is drive innovation and investment towards whatever theory of metaphysics is prevalant. It makes sense, thus, that over thirteen billion dollars would be spent over several years on finding the Higgs boson, in line with views of there being fundamental particles (Knapp, [2012](https://www.forbes.com/sites/alexknapp/2012/07/05/how-much-does-it-cost-to-find-a-higgs-boson/?sh=6dd18eb63948)). It also makes sense that there is such a fascination with "artificial intelligence" that we keep developing more complex neural networks and debating whether what the resulting machines do responds to some mechanistic notion of consciousness (e.g.: Weinberg, [2020](https://dailynous.com/2020/07/30/philosophers-gpt-3/)).

How we conceive of the world, in other words, shapes how we conduct science. And how we conduct science is a question of research ethics.

Pre-Hispanic Mesoamerican notions of reality shaped how they conducted themselves. The values of balancedness and reciprocity captured their understanding of the universe. A sort of communitarianism followed, whereby their actions were guided by the need to respectfully participate in the ever-changing yet homogeneous teotl.

The link between metaphysics and morality has not been broken by time. We currently pursue research questions that respond to our own views of the world. We conduct research following metaphysical assumptions, and how we conduct ourselves in research is a question of research ethics. How funds are allocated by organisations, time invested by researchers, and training courses delivered by academics; these are all factors to be scrutinised through the field of research ethics.

As stated at the start, there is an important struggle that scholars face when engaging with pre-Hispanic Mesoamerican societies; sources are hard to come by and often secondary. The historical challenges of centering indigenous voices and conducting research that is faithful to their realities will be further developed when discussing the role of Spanish conquistadors in shaping the narrative of ["The Conquest"](https://www.tiki-toki.com/timeline/entry/1753034/A-History-of-Research-Ethics/#vars!panel=16699328!).
