## Table of contents
* [Mission](#Mission)
* [Vision](#Vision)
* [The Gap](#The-Gap)
* [The Aims](#The-Aims)
* [The Method](#The-Method)
* [The Audience](#The-Audience)

## Mission
Bringing to life past events that inspire a more thoughtful science today.

## Vision
_An Incomplete History of Research Ethics_ provides a compilation of thought-provoking stories from our shared past. The project relies on community-led dialogue and rigorous research. Stories are delivered in short- and long-form, using accessible and fun formats. Through story-telling, we promote reflexivity across the research ecosystem.

## The Gap
Evolving initially from medicine to animal research and, more recently, to fields such as computer science and artificial intelligence (AI) research, the history of research ethics can serve to inform research institutions and practitioners. Indeed, it is often employed in training researchers on the ethical dimensions of their work. However, the literature drawn on for such training programmes depicts a history of research ethics that hinges on very select events, mostly from the twentieth century. Such events include the Milgram experiments, the Tuskegee syphilis study and Nazi experimentations, as well as important declarations that followed, such as the Nuremberg Code, the Helsinki Declaration and the Belmont Report.

*An Incomplete History of Research Ethics* enriches the narrative around both research ethics and its history by providing critical analyses of diverse historical events that both inform and challenge present research. It is both about filling the literature gap regarding the much lengthier and more complex history of research ethics, and making thought-provoking texts accessible.

## The Aims
*An Incomplete History of Research Ethics* has three overarching aims: to compile engaging stories, to deliver these in inclusive formats, and to provide narratives that are insightful to decision-makers in today's research landscape.

The first aim of *The Timeline* is to build a community-led approach to discovering and creating engaging stories that enrich modern conceptions of both research ethics and its history. This community must reflect on the very diversity of human history to provide critical analyses of its many interacting elements. The compiled stories in *An Incomplete History of Research Ethics* can then constitute policy-informing pedagogical resources.

The second aim is for stories to be shared as widely as possible. Through an interactive timeline, short synopses and long-reads, *An Incomplete History of Research Ethics* must be easily adapted for use by schools, universities and corporate training facilitators. To reach diverse audiences and share the important stories our past holds for modern research, *The Timeline* must be built on inclusive formats.

The third aim is for *An Incomplete History of Research Ethics* to serve decision makers. This includes business functions in research institutions, government bodies that shape research policy, and researchers themselves. This is done directly by providing prompts for discussion and reflection. The pedagogical nature of *The Timeline*'s outputs also support decision-makers indirectly by providing a foundation for further analyses and studies.

## The Method
Key to the success of *The Timeline* is its community-based approach to story development. Two discussions about methodology emerge from this. First, there is a question about the method of community-building. Second, there is a question about the method of story development.
### Community-building
Community-building will have passive and active elements. Passively, the community will be expected to grow as *The Timeline* grows. This will be by virtue of word-of-mouth, increasing interest in its contents from more diverse parties, and, perhaps, gaining influential advocates.

The active elements for *The Timeline*'s community-building process hinge on adaptable protocols. These [protocols](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics/blob/main/Protocols.md) set out a code of conduct, values to collaborate by, and clear processes for participating in the community. In particular, Protocol 7: Public Engagement is key to understanding the proactive role community members are encouraged to lead by prompting calls to action and encouraging advocacy. By sharing engaging stories from *The Timeline* in diverse settings, and reaching out to individuals and other communities, collaborators in *The Timeline*'s community can help it grow and become more useful to growing audiences.

It is key in community-building exercises that members acknowledge the value of *diversity* in the epistemic sense. That is to say that the intellectual tapistry of the community be as varied as possible. As the [readme](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics/blob/main/README.md) says, "philosophers, historians, lawyers, business professionals, butchers, bakers and candlestick makers" are all welcome to join. Some professional backgrounds that the community would benefit from are:
* **Historians writ large**, providing knowledge about different sociohistorical contexts;
* **Journalists**, supporting the creation of engaging writing styles;
* **Legal practitioners and academics**, delving into the nuance of past and present legal documents, their implications and their interpretations;
* **Philosophers**, building the intellectual context events took place in;
* **Scientists** who can distill the complex findings and explanations made by fellow physicists, astronomers, engineers, mathematicians, and so on;
* **Sociologists** who can speak to the sociology of science.

### Story development
Regarding story-development, there are two levels of abstraction to consider *The Timeline*'s method from. Firstly, there is the creation of individual stories. The method here is captured by two [protocols](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics/blob/main/Protocols.mdhttps://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics/blob/main/Protocols.md): Protocol 4: Lifecycle of A Story, and Protocol 5: Style Guide. In short, following brainstorming sessions (top-down and bottom-up processes are suggested in Protocol 4), research into events or influential documents is conducted to uncover whether they had importance for the conduct of research, or whether they can be insightful to modern audieen. If either of these is the case, the developing story can be announced with the aim of attracting collaborators. By working together on [this GitHub repository](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics), the story can be openly discussed, its narrative fine-tuned and its first draft agreed upon. Through further community engagement, a review process begins and the text is finally shared in *The Timeline*.

Secondly, there is a question as to how new stories are selected. How do we choose stories that are worthwhile in *The Timeline*? It is important to note that *An Incomplete History of Research Ethics* is not focussed on any period. This is to dispell the notion that research ethics began in the twentieth century, or any other superficial perspectives on the field. But then one must ask how to select stories from the endlessly deep well that is human history. The response, I believe, boils down to the value of diversity: *The Timeline* must be diverse both in terms of the regions its stories pertain to, and their time periods.

"Periodical diversity" can be attained by charting the story-counts by century. Whilst it is inevitable that more recent centuries provide more accessible events than earlier ones, we can study what periods have less stories to study them and develop pertinent stories from those more "barren" periods. Historians can provide particular insight when seeki these stories.

"Geographic diversity" amounts to stories relating with the entire globe. It might be easy to develop a history of research ethics that focusses on events that occurred in the Global North. Indeed, traditional accounts of the field's history focus on events in Europe and North America. To avoid this, *The Timeline*'s community must itself be diverse, so as to tap into different educational backgrounds that provide people with their region's own histories. Community members should feel encouraged, thus, to share their own experiences and understandings of history. By fostering an inclusive space, dialogue can make the contradictions between accounts more salient and inspire new stories.

## The Audience
Both the aims and the methods of *An Incomplete History of Research Ethics* must ensure relevance to as wide an audience as possible. As captured in [Protocol 7: Public Engagement](https://github.com/Ismael-KG/An_Incomplete_History_of_Research_Ethics/blob/main/Protocols.md#Protocol-7-Public-Engagement), *The Timeline* must appeal to both decision-makers in research and those wishing to develop their knowledge of the history and ethics of research.

This is an ambitious goal, as different audiences will engage with different types of content. Here, the aim of making *The Timeline* available in various and inclusive formats ensures that its contents is delivered in engaging ways to varied audiences. Meanwhile, the community-led approach to story development ensures that stories are relevant to different audiences. In this regard, it might be the case that a certain story is more relevant to research governance professionals, whilst another provides an insight that is particularly interesting to, say, philosophers. Whilst this may be the resulting case, Protocol 5: Style Guide requires that stories have short introductory lines, as well as summaries. This way, whilst a particular story might be more relevant to a particular audience, there is a very low barrier to engage with the basics of each and every story.
